"""Adapted from
https://earth.bsc.es/gitlab/digital-twins/de_340-2/workflow/-/blob/main/lib/runscript/run_opa.py
"""

from argparse import ArgumentParser
import sys

from pprint import pprint

from one_pass.opa import Opa
from opa_tools import get_request
from gsv import GSVRetriever

def _get_parser():
    parser = ArgumentParser(description="Runscript for OPA job.")
    parser.add_argument(
        "-r", "--request",
        type=int,
        required=True,
        help="Input request number"
    )
    parser.add_argument(
        "--read_from_databridge",
        type=bool,
        help="Read from databridge",
        default=False
    )
    parser.add_argument(
        "-b", "--benchmark",
        type=bool,
        help="Switch on benchmarking",
        default=False
    )
    return parser

def run_bias_adjustment(oparequest):  # type: ignore
    raise NotImplementedError(
        "OPA with bias adjustment not implemented in OPA-Tools package. "
        "Refer to the original script for implementation."
    )

def main(argv=None):
    if argv is None:
        argv = sys.argv

    args = _get_parser().parse_args(argv[1:])
    request = args.request
    read_from_databridge = args.read_from_databridge

    gsvrequest, oparequest = get_request(request)
    print("\nGSV REQUEST:\n============\n")
    pprint(gsvrequest)
    print("\nOPA REQUEST:\n============\n")
    pprint(oparequest)

    gsv = GSVRetriever()
    data = gsv.request_data(
        gsvrequest,
        use_stream_iterator=read_from_databridge
    )

    if oparequest["stat"] == "raw" and oparequest["bias_adjustment"] is True:
        run_bias_adjustment(oparequest)

    else:
        opa_stat = Opa(oparequest)
        opa_stat.compute(data)

if __name__ == "__main__":
    main()
